@@ -105,7 +105,12 @@ def main():
     print(f"lstmcpipe config saved in {output}")
 
     lstchain_file = f'lstchain_config_{date.today()}.json' if args.lstchain_conf is None else args.lstchain_conf
-    dump_lstchain_std_config(filename=lstchain_file, overwrite=args.overwrite)
+
+    if 'AllSky' in args.config_class:
+        allsky = True
+    else:
+        allsky = False
+    dump_lstchain_std_config(filename=lstchain_file, allsky=allsky, overwrite=args.overwrite)
     print(f"To start the process with dumped configs, run:\n\nlstmcpipe -c {output} -conf_lst {lstchain_file}\n\n")
 
 
