@@ -3,12 +3,11 @@
 # DL2 to IRFs stage for the R0 to IRFs full MC production workflow.
 # As all the previous stages, this script make use of the lstchain entry points to batch each workflow stage.
 
-import os
 import shutil
 import logging
 from pathlib import Path
-from lstmcpipe.workflow_management import save_log_to_file
-from lstmcpipe.io.data_management import check_and_make_dir_without_verification
+from ..utils import save_log_to_file, SbatchLstMCStage
+from ..io.data_management import check_and_make_dir_without_verification
 
 
 log = logging.getLogger(__name__)
@@ -51,14 +50,13 @@ def batch_dl2_to_irfs(
     debug_log = {}
 
     for paths in dict_paths:
-
         job_logs, jobid = dl2_to_irfs(
-            paths["input"]["gamma_file"],
-            paths["input"]["electron_file"],
-            paths["input"]["proton_file"],
+            paths["input"]["gamma_file"],  # gamma_file must always be provided
+            paths["input"].get("electron_file", None),  # electron_file might be missing in case of point-like IRFs
+            paths["input"].get("proton_file", None),   # proton_file might be missing in case of point-like IRFs
             paths["output"],
             config_file=config_file,
-            irf_point_like=paths["options"],
+            options=paths.get("options", None),
             batch_configuration=batch_config,
             wait_jobs_dl1dl2=job_ids_from_dl1_dl2,
             slurm_options=paths.get("slurm_options", None),
@@ -86,7 +84,7 @@ def dl2_to_irfs(
     proton_file,
     outfile,
     config_file,
-    irf_point_like,
+    options,
     batch_configuration,
     wait_jobs_dl1dl2,
     slurm_options=None,
@@ -102,8 +100,9 @@ def dl2_to_irfs(
     outfile: str
     config_file: str
         Path to a configuration file. If none is given, a standard configuration is applied
-    irf_point_like: str
-        MC prod configuration argument to create IRFs: {True: gamma, False: gamma-diffuse}.
+    options: str  | None
+        options to pass to lstchain_create_irf_files as a string
+        Most common: --irf-point-like
     batch_configuration : dict
         Dictionary containing the (full) source_environment and the slurm_account strings to be passed to the
         sbatch commands
@@ -120,42 +119,35 @@ def dl2_to_irfs(
     job_id_dl2_irfs: str
         Job-id of the batched job to be passed to the last (MC prod check) stage of the workflow.
     """
-    source_env = batch_configuration["source_environment"]
-    slurm_account = batch_configuration["slurm_account"]
-
     output_dir = Path(outfile).parent
-
     log_dl2_to_irfs = {}
 
     check_and_make_dir_without_verification(output_dir)
 
-    cmd = f"lstchain_create_irf_files {irf_point_like} -g {gamma_file} -o {outfile} "
+    options = '' if options is None else options
+    cmd = f"lstchain_create_irf_files {options} -g {gamma_file} -o {outfile} "
     if proton_file is not None:
         cmd += f" -p {proton_file}"
     if electron_file is not None:
         cmd += f" -e {electron_file}"
-
     if config_file:
         cmd += f" --config={config_file}"
 
     log.info(f"Output dir IRF of {gamma_file}: {output_dir}")
 
-    jobe = Path(output_dir).joinpath("job_dl2_to_irfs-%j.e").resolve().as_posix()
-    jobo = Path(output_dir).joinpath("job_dl2_to_irfs-%j.o").resolve().as_posix()
+    sbatch_dl2_irfs = SbatchLstMCStage(
+        "dl2_to_irfs",
+        wrap_command=cmd,
+        slurm_error=Path(output_dir).joinpath("job_dl2_to_irfs-%j.e").resolve().as_posix(),
+        slurm_output=Path(output_dir).joinpath("job_dl2_to_irfs-%j.o").resolve().as_posix(),
+        slurm_deps=wait_jobs_dl1dl2,
+        slurm_options=slurm_options,
+        slurm_account=batch_configuration["slurm_account"],
+        source_environment=batch_configuration["source_environment"],
+    )
 
-    batch_cmd = "sbatch --parsable"
-    if slurm_options is not None:
-        batch_cmd += f" {slurm_options}"
-    else:
-        batch_cmd += " -p short"
-    if slurm_account != "":
-        batch_cmd += f" -A {slurm_account}"
-    if wait_jobs_dl1dl2 is not None:
-        batch_cmd += f" --dependency=afterok:{wait_jobs_dl1dl2}"
-    batch_cmd += f" -J dl2_IRF" f' -e {jobe} -o {jobo} --wrap="{source_env} {cmd}"'
-
-    job_id_dl2_irfs = os.popen(batch_cmd).read().strip("\n")
-    log_dl2_to_irfs.update({job_id_dl2_irfs: batch_cmd})
+    job_id_dl2_irfs = sbatch_dl2_irfs.submit()
+    log_dl2_to_irfs.update({job_id_dl2_irfs: sbatch_dl2_irfs.slurm_command})
 
     log.info(f"Submitted batch job {job_id_dl2_irfs}")
 
