@@ -1,9 +1,8 @@
 #!/usr/bin/env python
 
-import os
 import logging
 from pathlib import Path
-from lstmcpipe.workflow_management import save_log_to_file
+from ..utils import save_log_to_file, SbatchLstMCStage
 
 
 log = logging.getLogger(__name__)
@@ -107,48 +106,43 @@ def dl2_to_sensitivity(
     p_file = input_paths["proton_file"]
     e_file = input_paths["electron_file"]
 
-    source_env = batch_configuration["source_environment"]
-    slurm_account = batch_configuration["slurm_account"]
+    cmd_sens = f"lstmcpipe_dl2_to_sensitivity -g {g_file} -p {p_file} -e {e_file} -o {output}"
 
-    # TODO Move the base commands into scripts so that we can use subprocess properly(makes splitting the string easier)
-    base_cmd_sens = f"lstmcpipe_dl2_to_sensitivity -g {g_file} -p {p_file} -e {e_file} -o {output}"
+    sbatch_dl2_sens = SbatchLstMCStage(
+        "dl2_sens",  # --partition=short --mem=32G
+        wrap_command=cmd_sens,
+        slurm_error=Path(output).parent.joinpath("job_dl2_to_sensitivity.e"),
+        slurm_output=Path(output).parent.joinpath("job_dl2_to_sensitivity.o"),
+        slurm_deps=wait_jobs_dl1_dl2,
+        slurm_options=slurm_options,
+        slurm_account=batch_configuration["slurm_account"],
+        source_environment=batch_configuration["source_environment"],
+    )
 
-    jobo_sens = Path(output).parent.joinpath("job_dl2_to_sensitivity.o")
-    jobe_sens = Path(output).parent.joinpath("job_dl2_to_sensitivity.e")
-
-    cmd_sens = "sbatch --parsable -p short --mem 32G"
-    if slurm_account != "":
-        cmd_sens += f" -A {slurm_account}"
-    if wait_jobs_dl1_dl2 is not None:
-        cmd_sens += f" --dependency=afterok:{wait_jobs_dl1_dl2}"
-    cmd_sens += f" -e {jobe_sens} -o {jobo_sens}" f' -J dl2_sens --wrap="{source_env} {base_cmd_sens}"'
-
-    job_id_dl2_sens = os.popen(cmd_sens).read().strip("\n")
-    log_dl2_to_sensitivity.update({job_id_dl2_sens: cmd_sens})
+    job_id_dl2_sens = sbatch_dl2_sens.submit()
+    log_dl2_to_sensitivity.update({job_id_dl2_sens: job_id_dl2_sens.slurm_command})
     jobids_dl2_to_sensitivity.append(job_id_dl2_sens)
 
     log.info(f"Output dir of sensitivity file: {output}")
     log.info(f"Submitted batch job {job_id_dl2_sens}")
 
     # Create plot from sensitivity files
-    base_cmd_plot = f'lstmcpipe_plot_irfs -f {output} -o {output.replace(".fits.gz", ".png")}'
-    jobe_plot = Path(output).parent.joinpath("job_plot_sensitivity-%j.e")
-    jobo_plot = Path(output).parent.joinpath("job_plot_sensitivity-%j.o")
+    cmd_plot_sens = f'lstmcpipe_plot_irfs -f {output} -o {output.replace(".fits.gz", ".png")}'
 
-    cmd_plot = "sbatch --parsable"
-    if slurm_options is not None:
-        cmd_plot += f" {slurm_options}"
-    else:
-        cmd_plot += " -p short"
-    if slurm_account != "":
-        cmd_plot += f" -A {slurm_account}"
-    cmd_plot += (
-        f" --dependency=afterok:{job_id_dl2_sens} -e {jobe_plot} -o {jobo_plot}"
-        f' -J dl2_sens_plot --wrap="export MPLBACKEND=Agg; {source_env} {base_cmd_plot}"'
+    sbatch_plot_sens = SbatchLstMCStage(
+        "dl2_sens_plot",  # --partition=short
+        wrap_command=cmd_plot_sens,
+        slurm_error=Path(output).parent.joinpath("job_plot_sensitivity-%j.e"),
+        slurm_output=Path(output).parent.joinpath("job_plot_sensitivity-%j.o"),
+        slurm_deps=job_id_dl2_sens,
+        slurm_options=slurm_options,
+        slurm_account=batch_configuration["slurm_account"],
+        source_environment=batch_configuration["source_environment"],
+        backend="export MPLBACKEND=Agg; ",
     )
 
-    job_id_plot_sens = os.popen(cmd_plot).read().strip("\n")
-    log_dl2_to_sensitivity.update({job_id_plot_sens: cmd_plot})
+    job_id_plot_sens = sbatch_plot_sens.submit()
+    log_dl2_to_sensitivity.update({job_id_plot_sens: sbatch_plot_sens.slurm_command})
     jobids_dl2_to_sensitivity.append(job_id_plot_sens)
 
     log.info(f"Output dir of sensitivity plots: {output}")
